==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/cleantwertepart.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS cleantwertepart//
create procedure cleantwertepart()
  deterministic
  sql security invoker
  begin
    declare i, z, p, n, dtn integer;
    declare td date;
    declare selcur cursor for select ID, testdatum,
        (select count(*) from difftos where difftos.ID = wi.ID) as ndt
      from wi
      where wtab = 'twerte' and ID % n = p order by ID;
    declare continue handler for not found set z = 1;

    select count(*) from information_schema.partitions
      where table_schema = 'logging' and table_name = 'twerte' into n;

    set p = 0;
    while p < n do
      set z = 0;
      open selcur;
      fetch selcur into i, td, dtn;
      while z != 1 do
        if dtn > 0 then
          delete twerte from twerte
            left join difftos on difftos.ID = werteindizesID and difftos.dt = datum
            where werteindizesID = i and datum < td and difftos.ID is NULL;
        else
          delete from twerte where werteindizesID=i and datum < td;
        end if;
        fetch selcur into i, td, dtn;
      end while;
      close selcur;

      if n > 1 then
        set @psel = (select concat('alter table twerte optimize partition ',
                      group_concat(PARTITION_NAME separator ','))
          from information_schema.partitions
          where table_schema = 'logging' and table_name = 'twerte' and DATA_FREE > 0
          group by table_name);
        if @psel is not NULL then
          set @st = unix_timestamp();
          select @psel;
          prepare ostmt from @psel;
          execute ostmt;
          select sleep((unix_timestamp() - @st)/2);
        end if;
      else
        optimize table twerte;
      end if;

      set p = p + 1;
    end while;
  end//

GRANT EXECUTE on PROCEDURE cleantwertepart to loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/cleantwertepart.sql <==
-- cleantwertepart.sql
--
-- procedure cleantwertepart()
-- 
-- remove old values from table twerte
-- if the table is partitoned, remove partitions separatedly

set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS cleantwertepart//
create procedure cleantwertepart()
  deterministic
  sql security invoker
  begin
    declare i, z, p, n, dtn integer;
    declare td date;
    declare selcur cursor for select ID, testdatum,
        (select count(*) from difftos where difftos.ID = wi.ID) as ndt
      from wi
      where wtab = 'twerte' and ID % n = p order by ID;
    declare continue handler for not found set z = 1;

    select count(*) into n from information_schema.partitions
      where table_schema = 'logging' and table_name = 'twerte';

    set p = 0;
    while p < n do
      set z = 0;
      open selcur;
      fetch selcur into i, td, dtn;
      while z != 1 do
        if dtn > 0 then
          delete twerte from twerte
            left join difftos on difftos.ID = werteindizesID and difftos.dt = datum
            where werteindizesID = i and datum < td and difftos.ID is NULL;
        else
          delete from twerte where werteindizesID=i and datum < td;
        end if;
        fetch selcur into i, td, dtn;
      end while;
      close selcur;

      if n > 1 then
        set @psel = (select concat('alter table twerte optimize partition ',
                      group_concat(PARTITION_NAME separator ','))
          from information_schema.partitions
          where table_schema = 'logging' and table_name = 'twerte' and DATA_FREE > 0
          group by table_name);
        if @psel is not NULL then
          set @st = unix_timestamp();
          select @psel;
          prepare ostmt from @psel;
          execute ostmt;
          drop prepare ostmt;
          select sleep((unix_timestamp() - @st)/2);
        end if;
      else
        optimize table twerte;
      end if;

      set p = p + 1;
    end while;
  end//
